@@ -792,8 +792,13 @@ class IncidentPublisher(PollMixin, unittest.TestCase):
         t.logger.setLogDir(logdir)
         t.logger.setIncidentReporterFactory(incident.NonTrailingIncidentReporter)
         # dump some other files in the incident directory
-        open(os.path.join(logdir, "distraction.bz2"), "w").write("stuff")
-        open(os.path.join(logdir, "noise"), "w").write("stuff")
+        f = open(os.path.join(logdir, "distraction.bz2"), "w")
+        f.write("stuff")
+        f.close()
+        f = open(os.path.join(logdir, "noise"), "w")
+        f.write("stuff")
+        f.close()
+
         # fill the buffers with some messages
         t.logger.msg("one")
         t.logger.msg("two")
@@ -1891,7 +1896,7 @@ class Dumper(unittest.TestCase, LogfileWriterMixin, LogfileReaderMixin):
         return d
 
     def test_oops_furl(self):
-        self.basedir = "logging/Dumper/oops_furl"
+        self.basedir = os.path.join("logging", "Dumper", "oops_furl")
         if not os.path.exists(self.basedir):
             os.makedirs(self.basedir)
         fn = os.path.join(self.basedir, "logport.furl")
@@ -1905,7 +1910,7 @@ class Dumper(unittest.TestCase, LogfileWriterMixin, LogfileReaderMixin):
         d.options.parseOptions([fn])
         argv = ["flogtool", "dump", fn]
         (out,err) = cli.run_flogtool(argv[1:], run_by_human=False)
-        self.failUnlessEqual(err, "Error: logging/Dumper/oops_furl/logport.furl appears to be a FURL file.\nPerhaps you meant to run 'flogtool tail' instead of 'flogtool dump'?\n")
+        self.failUnlessEqual(err, "Error: %s appears to be a FURL file.\nPerhaps you meant to run 'flogtool tail' instead of 'flogtool dump'?\n" % fn)
 
 class Filter(unittest.TestCase, LogfileWriterMixin, LogfileReaderMixin):
 
