@@ -3,6 +3,7 @@ from twisted.trial import unittest
 
 from twisted.internet import protocol, defer, reactor
 from twisted.application import internet
+from twisted.web.client import getPage
 from foolscap import pb, negotiate, tokens, eventual
 from foolscap.api import Referenceable, Tub, UnauthenticatedTub, BananaError
 from foolscap.eventual import flushEventualQueue
@@ -75,20 +76,6 @@ class Target(Referenceable):
         self.calls += 1
 
 
-def getPage(url):
-    """This is a variant of the standard twisted.web.client.getPage, which is
-    smart enough to shut off its connection when its done (even if it fails).
-    """
-    from twisted.web import client
-    scheme, host, port, path = client._parse(url)
-    factory = client.HTTPClientFactory(url)
-    c = reactor.connectTCP(host, port, factory)
-    def shutdown(res, c):
-        c.disconnect()
-        return res
-    factory.deferred.addBoth(shutdown, c)
-    return factory.deferred
-
 class OneTimeDeferred(defer.Deferred):
     def callback(self, res):
         if self.called:
@@ -1194,23 +1181,3 @@ class Replacement(BaseMixin, unittest.TestCase):
         # the old rref should be broken (eventually)
         d.addCallback(lambda res: d2)
         return d
-
-
-
-
-# disable all tests unless NEWPB_TEST_NEGOTIATION is set in the environment.
-# The negotiation tests are sensitive to system load, and the intermittent
-# failures are really annoying. The 'right' solution to this involves
-# completely rearchitecting connection establishment, to provide debug/test
-# hooks to get control in between the various phases. It also requires
-# creating a loopback connection type (as a peer of TCP) which has
-# deterministic timing behavior.
-
-#import os
-if False: #not os.environ.get("NEWPB_TEST_NEGOTIATION"):
-    del Basic
-    del Versus
-    del Parallel
-    del CrossfireReverse
-    del Crossfire
-    del Existing
