@@ -108,7 +108,7 @@ class SetLocation(unittest.TestCase):
             if sr.encrypted:
                 for lh in sr.locationHints:
                     self.failUnlessEqual(lh[2], portnum, lh)
-                self.failUnless( ("ipv4", "127.0.0.1", portnum)
+                self.failUnless( ("tcp", "127.0.0.1", portnum)
                                  in sr.locationHints)
             else:
                 # TODO: unauthenticated tubs need review, I think they
@@ -473,4 +473,3 @@ class BadLocationFURL(unittest.TestCase):
             self.failUnless(f.check(NoLocationHintsError), f)
         d.addBoth(_check)
         return d
-    
